@@ -1323,7 +1323,7 @@ void enable_musepack_widgets(void)
 
 #if GTK_MINOR_VERSION >= 6
 static const char* 
-GBLprogramName = "Asunder 1.9.3";
+GBLprogramName = "Asunder 2.0";
 
 static const char* 
 GBLauthors[2] = {
@@ -1351,6 +1351,12 @@ GBLauthors[2] = {
 "http://wooptoo.com/\n"
 "- The new Asunder icon\n"
 "\n"
+"Pader Reszo\n"
+"- Made the about description translatable\n"
+"\n"
+"Cyril Brulebois\n"
+"- A kFreeBSD fix.\n"
+"\n"
 "Packages:\n"
 "\n"
 "Toni Graffy\n"
@@ -1434,11 +1440,14 @@ GBLtranslators =
 "- el (Greek) translation of Asunder versions 0.8 - 1.0, 1.9\n"
 "\n"
 "George Vlahavas\n"
-"- el (Greek) translation of Asunder versio 1.5\n"
-"\n"
+"- el (Greek) translation of Asunder version 1.5\n"
+"\n"   
 "Juan Garcia-Murga Monago\n"
 "- es (Spanish) translation of Asunder versions 0.8 - 1.9\n"
 "\n"
+"Marco Antonio\n"
+"- es (Spanish) translation of Asunder version 1.9.3\n"
+"\n"
 "Eero Salokannel\n"
 "- fi (Finnish) translation of Asunder versions 0.8 - 1.5\n"
 "\n"
@@ -1450,6 +1459,9 @@ GBLtranslators =
 "\n"         
 "Peter Polonkai\n"
 "- hu (Hungarian) translation of Asunder versions 0.8 - 1.9\n"
+"\n"      
+"Petar Kulic\n"
+"- hr (Croatian) translation of Asunder version 1.9\n"
 "\n"
 "Pader Rezso\n"
 "- hu (Hungarian) translation of Asunder version 1.9.2\n"
@@ -1487,6 +1499,9 @@ GBLtranslators =
 "Antonio Sousa\n"
 "- pt (Portuguese) translation of Asunder version 1.5\n"
 "\n"
+"Sergio Marques\n"
+"- pt (Portuguese) translation of Asunder version 1.9\n"
+"\n"
 "Flipe Augusto\n"
 "- pt_BR (Portuguese/Brazil) translation of Asunder versions 0.8.1 - 1.9\n"
 "\n"
@@ -1529,8 +1544,9 @@ GBLtranslators =
 
 static const char* 
 GBLcomments = 
-"An application to save tracks from an Audio CD \n"
-"as WAV, MP3, OGG, FLAC, and/or Wavpack.";
+N_("An application to save tracks from an Audio CD \n"
+"as WAV, MP3, OGG, FLAC, Wavpack, Musepack, Monkey's Audio, and/or "
+"AAC files.");
 
 static const char* 
 GBLcopyright = 
@@ -1555,7 +1571,7 @@ show_aboutbox (void)
 #endif
                           "authors", GBLauthors,
                           "translator-credits", GBLtranslators,
-                          "comments", GBLcomments,
+                          "comments", _(GBLcomments),
                           "copyright", GBLcopyright,
                           "license", GBLlicense,
                           "website", GBLwebsite,
