@@ -137,11 +137,23 @@ void dorip()
     aac_percent = 0.0;
     rip_tracks_completed = 0;
     encode_tracks_completed = 0;
-    
+
+    // get year
+    GtkTreeIter iter;
+    GtkListStore * store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(lookup_widget(win_main, "tracklist"))));
+    gboolean rowsleft = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter);
+    unsigned year = 0;
+    if(rowsleft)
+    {
+        gtk_tree_model_get(GTK_TREE_MODEL(store), &iter,
+                           COL_YEAR, &year,
+                           -1);
+    }
+
     const char * albumartist = gtk_entry_get_text(GTK_ENTRY(lookup_widget(win_main, "album_artist")));
     const char * albumtitle = gtk_entry_get_text(GTK_ENTRY(lookup_widget(win_main, "album_title")));
-    char * albumdir = parse_format(global_prefs->format_albumdir, 0, albumartist, albumtitle, NULL);
-    char * playlist = parse_format(global_prefs->format_playlist, 0, albumartist, albumtitle, NULL);
+    char * albumdir = parse_format(global_prefs->format_albumdir, 0, year, albumartist, albumtitle, NULL);
+    char * playlist = parse_format(global_prefs->format_playlist, 0, year, albumartist, albumtitle, NULL);
     
     overwriteAll = false;
     overwriteNone = false;
@@ -166,9 +178,7 @@ void dorip()
     }
     
     // make sure there's some tracks to rip
-    GtkListStore * store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(lookup_widget(win_main, "tracklist"))));
-    GtkTreeIter iter;
-    gboolean rowsleft = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter);
+    rowsleft = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter);
     tracks_to_rip = 0;
     int riptrack;
     while(rowsleft)
@@ -343,12 +353,14 @@ gpointer rip(gpointer data)
     gdk_threads_leave();
     while(rowsleft)
     {
+        unsigned year = 0;
         gdk_threads_enter();
             gtk_tree_model_get(GTK_TREE_MODEL(store), &iter,
                 COL_RIPTRACK, &riptrack,
                 COL_TRACKNUM, &tracknum,
                 COL_TRACKARTIST, &trackartist,
                 COL_TRACKTITLE, &tracktitle,
+                COL_YEAR, &year,
                 -1);
         gdk_threads_leave();
         
@@ -359,8 +371,8 @@ gpointer rip(gpointer data)
         
         if (riptrack)
         {
-            albumdir = parse_format(global_prefs->format_albumdir, 0, albumartist, albumtitle, NULL);
-            musicfilename = parse_format(global_prefs->format_music, tracknum, trackartist, albumtitle, tracktitle);
+            albumdir = parse_format(global_prefs->format_albumdir, 0, year, albumartist, albumtitle, NULL);
+            musicfilename = parse_format(global_prefs->format_music, tracknum, year, trackartist, albumtitle, tracktitle);
             wavfilename = make_filename(prefs_get_music_dir(global_prefs), albumdir, musicfilename, "wav");
             
             debugLog("Ripping track %d to \"%s\"\n", tracknum, wavfilename);
@@ -437,6 +449,7 @@ gpointer encode(gpointer data)
     
     char* album_artist = NULL;
     char* album_title = NULL;
+    char* album_genre = NULL;		// lnr
     
     char* albumdir = NULL;
     char* musicfilename = NULL;
@@ -455,7 +468,8 @@ gpointer encode(gpointer data)
     gdk_threads_enter();
         GtkListStore * store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(lookup_widget(win_main, "tracklist"))));
         gboolean single_artist = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(win_main, "single_artist")));
-        
+        gboolean single_genre  = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(win_main, "single_genre")));	// lnr
+
         const char * temp_album_artist = gtk_entry_get_text(GTK_ENTRY(lookup_widget(win_main, "album_artist")));
         album_artist = malloc(sizeof(char) * (strlen(temp_album_artist)+1));
         if (album_artist == NULL)
@@ -465,11 +479,18 @@ gpointer encode(gpointer data)
         const char * temp_album_title = gtk_entry_get_text(GTK_ENTRY(lookup_widget(win_main, "album_title")));
         album_title = malloc(sizeof(char) * (strlen(temp_album_title)+1));
         if (album_title == NULL)
-            fatalError("malloc(sizeof(char) * (strlen(temp_album_artist)+1)) failed. Out of memory.");
+            fatalError("malloc(sizeof(char) * (strlen(temp_album_title)+1)) failed. Out of memory.");
         strncpy(album_title, temp_album_title, strlen(temp_album_title)+1);
 
+        const char * temp_album_genre = gtk_entry_get_text(GTK_ENTRY(lookup_widget(win_main, "album_genre")));	// lnr
+        album_genre = malloc(sizeof(char) * (strlen(temp_album_genre)+1));
+        if (album_genre == NULL)
+            fatalError("malloc(sizeof(char) * (strlen(temp_album_genre)+1)) failed. Out of memory.");
+        strcpy( album_genre, temp_album_genre );
+
         gboolean rowsleft = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter);
     gdk_threads_leave();
+
     while(rowsleft)
     {
         g_mutex_lock(barrier);
@@ -499,16 +520,19 @@ gpointer encode(gpointer data)
             yearStrPtr = NULL;
         else
             yearStrPtr = yearStr;
-        
+
         if (single_artist)
         {
             trackartist = album_artist;
         }
+
+        if ( single_genre )				// lnr
+            genre	= album_genre;
         
         if (riptrack)
         {
-            albumdir = parse_format(global_prefs->format_albumdir, 0, album_artist, album_title, NULL);
-            musicfilename = parse_format(global_prefs->format_music, tracknum, trackartist, album_title, tracktitle);
+            albumdir = parse_format(global_prefs->format_albumdir, 0, year, album_artist, album_title, NULL);
+            musicfilename = parse_format(global_prefs->format_music, tracknum, year, trackartist, album_title, tracktitle);
             wavfilename = make_filename(prefs_get_music_dir(global_prefs), albumdir, musicfilename, "wav");
             mp3filename = make_filename(prefs_get_music_dir(global_prefs), albumdir, musicfilename, "mp3");
             oggfilename = make_filename(prefs_get_music_dir(global_prefs), albumdir, musicfilename, "ogg");
@@ -537,7 +561,7 @@ gpointer encode(gpointer data)
                 }
                 else
                     doEncode = true;
-                
+
                 if(doEncode)
                     lame(tracknum, trackartist, album_title, tracktitle, genre, yearStrPtr, wavfilename, mp3filename, 
                          global_prefs->mp3_vbr, global_prefs->mp3_bitrate, &mp3_percent);
@@ -571,7 +595,7 @@ gpointer encode(gpointer data)
                     doEncode = true;
                 
                 if(doEncode)
-                    oggenc(tracknum, trackartist, album_title, tracktitle, genre, wavfilename, 
+                    oggenc(tracknum, trackartist, album_title, tracktitle, yearStrPtr, genre, wavfilename, 
                            oggfilename, global_prefs->ogg_quality, &ogg_percent);
                 
                 if (aborted) g_thread_exit(NULL);
@@ -803,6 +827,7 @@ gpointer encode(gpointer data)
     
     free(album_artist);
     free(album_title);
+    free(album_genre);
     
     if (playlist_wav) fclose(playlist_wav);
     playlist_wav = NULL;
@@ -907,14 +932,22 @@ gpointer track(gpointer data)
                  monkey_percent*100,musepack_percent*100,aac_percent*100);
         
         prip = (rip_tracks_completed+rip_percent) / tracks_to_rip;
-        snprintf(srip, 13, "%d%% (%d/%d)", (int)(prip*100), rip_tracks_completed, tracks_to_rip);
+        snprintf(srip, 13, "%d%% (%d/%d)", (int)(prip*100),
+                 (rip_tracks_completed < tracks_to_rip)
+                     ? (rip_tracks_completed + 1)
+                     : tracks_to_rip,
+                 tracks_to_rip);
         if (parts > 1)
         {
             pencode = ((double)encode_tracks_completed/(double)tracks_to_rip) + 
                        ((mp3_percent+ogg_percent+flac_percent+wavpack_percent+monkey_percent
                          +musepack_percent+aac_percent) /
                         (parts-1) / tracks_to_rip);
-            snprintf(sencode, 13, "%d%% (%d/%d)", (int)(pencode*100), encode_tracks_completed, tracks_to_rip);
+            snprintf(sencode, 13, "%d%% (%d/%d)", (int)(pencode*100),
+                     (encode_tracks_completed < tracks_to_rip)
+                         ? (encode_tracks_completed + 1)
+                         : tracks_to_rip,
+                     tracks_to_rip);
             ptotal = prip/parts + pencode*(parts-1)/parts;
         } else {
             ptotal = prip;
